from datetime import datetime
import calendar
from injectable import injectable


DEFAULT_DATE_FORMAT = '%d.%m.%Y %H:%M:%S'


@injectable
class UtilsTime:
    def get_current_timestamp_ms(self) -> int:
        return int(round(datetime.now().timestamp() * 1000))

    def format_timestamp_ms(self, timestamp_ms: int, date_format: str = DEFAULT_DATE_FORMAT) -> str:
        return datetime.fromtimestamp(timestamp_ms / 1000).strftime(date_format)

    def parse_timestamp_ms(self, date_str: str, date_format: str = DEFAULT_DATE_FORMAT) -> int:
        return int(round(datetime.strptime(date_str, date_format).timestamp() * 1000))

    def get_number_of_days_in_month(self, year: int, month: int) -> int:
        x, number_of_days_in_month = calendar.monthrange(year, month)
        return number_of_days_in_month



from PIL import Image as image_pil_main
from PIL.Image import Image
import cv2
import numpy
from numpy import ndarray
from injectable import injectable


@injectable
class UtilsImage:
    def convert_image_pil_to_image_cv(self, image_pil: Image) -> ndarray:
        return cv2.cvtColor(numpy.array(image_pil), cv2.COLOR_RGB2BGR)

    def convert_image_cv_to_image_pil(self, image_cv: ndarray) -> Image:
        return image_pil_main.fromarray(cv2.cvtColor(image_cv, cv2.COLOR_BGR2RGB))

    def open_image_pil(self, image_path: str) -> Image:
        return image_pil_main.open(image_path)

    def open_image_cv(self, image_path: str) -> ndarray:
        return self.convert_image_pil_to_image_cv(self.open_image_pil(image_path))

    def save_image_pil(self, image_pil: Image, image_path: str) -> str:
        image_pil.save(image_path)
        return image_path

    def debug_image_cv(self, image_cv: ndarray, window_name: str = 'Debug Image'):
        cv2.namedWindow(window_name, cv2.WINDOW_NORMAL)
        cv2.imshow(window_name, image_cv)
        cv2.waitKey(0)
        cv2.destroyAllWindows()


